"""
Configs migration

Generation datetime: 2020-12-09 10:19:43.942871
"""

from configs_core.migration.db_migrate_helper import DatabaseMigrationHelper as mh

REVISION = "90b9a9b8"
DOWN_REVISION = "84fe2546"


def upgrade():
    """Upgrade configs to new revision"""

    # limitation to rename
    mh.renameLimitation("LUNA_IMAGE_STORE_SAMPLES_ADDRESS", "LUNA_IMAGE_STORE_FACES_SAMPLES_ADDRESS")
    mh.renameLimitation("LUNA_IMAGE_STORE_SAMPLES_TIMEOUTS", "LUNA_IMAGE_STORE_FACES_SAMPLES_TIMEOUTS")

    # limitations to add
    mh.addLimitation(
        limitationName="LUNA_IMAGE_STORE_BODIES_SAMPLES_ADDRESS",
        validationSchema={
            "type": "object",
            "properties": {
                "origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                },
                "api_version": {"type": "integer"},
                "bucket": {"type": "string"},
            },
            "required": ["origin", "api_version", "bucket"],
            "additionalProperties": False,
        },
        defaultValue={
            "origin": "http://127.0.0.1:5020",
            "api_version": 1,
            "bucket": "visionlabs-bodies-samples",
        },
        description="Address of service for storing bodies samples",
        services=["luna-admin", "luna-api", "luna-handlers", "luna-tasks"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_IMAGE_STORE_BODIES_SAMPLES_TIMEOUTS",
        validationSchema={
            "type": "object",
            "properties": {
                "request": {"type": "number", "exclusiveMinimum": 0},
                "connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_read": {"type": "number", "exclusiveMinimum": 0},
            },
            "description": "timeouts in seconds",
            "additionalProperties": False,
        },
        defaultValue={
            "request": 60,
            "connect": 20,
            "sock_connect": 10,
            "sock_read": 60,
        },
        description="timeouts for http-request to luna-image-store service",
        services=["luna-api", "luna-handlers", "luna-tasks"],
        groupNames=["luna-platform"],
    )


def downgrade():
    """Downgrade configs to previous revision"""

    # limitation to rename
    mh.renameLimitation("LUNA_IMAGE_STORE_FACES_SAMPLES_ADDRESS", "LUNA_IMAGE_STORE_SAMPLES_ADDRESS")
    mh.renameLimitation("LUNA_IMAGE_STORE_FACES_SAMPLES_TIMEOUTS", "LUNA_IMAGE_STORE_SAMPLES_TIMEOUTS")

    # limitations to remove
    mh.removeLimitation(limitationName="LUNA_IMAGE_STORE_BODIES_SAMPLES_ADDRESS")
    mh.removeLimitation(limitationName="LUNA_IMAGE_STORE_BODIES_SAMPLES_TIMEOUTS")
