"""
Configs migration

Generation datetime: 2021-01-11 14:10:29.068061
"""

from typing import List

from configs_core.migration.db_migrate_helper import DatabaseMigrationHelper as mh, LimitationToModify

REVISION = "ed4b0195"
DOWN_REVISION = "10472e12"


limitationsToModify: List[LimitationToModify] = [
    LimitationToModify(
        limitationName="STORAGE_TIME",
        oldServices=[
            "luna-backport3",
            "luna-configurator",
            "luna-events",
            "luna-faces",
            "luna-handlers",
            "luna-index-manager",
            "luna-matcher-proxy",
            "luna-python-matcher",
            "luna-tasks",
        ],
        newServices=[
            "luna-admin",
            "luna-backport3",
            "luna-configurator",
            "luna-events",
            "luna-faces",
            "luna-handlers",
            "luna-index-manager",
            "luna-matcher-proxy",
            "luna-python-matcher",
            "luna-tasks",
        ],
        settingUpgradeFunction=None,
        settingDowngradeFunction=None,
    ),
]


def upgrade():
    """Upgrade configs to new revision"""

    # limitations to add
    mh.addLimitation(
        limitationName="LUNA_ADMIN_ACTIVE_PLUGINS",
        validationSchema={"type": "array", "items": {"type": "string"}},
        defaultValue=[],
        description="list active plugins for luna-admin",
        services=["luna-admin"],
        groupNames=["luna-platform"],
    )

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)


def downgrade():
    """Downgrade configs to previous revision"""

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)

    # limitations to remove
    mh.removeLimitation(limitationName="LUNA_ADMIN_ACTIVE_PLUGINS")
