"""
Configs migration

Generation datetime: 2022-12-13 12:55:11.093165
"""

from typing import List

from configs_core.migration.db_migrate_helper import (
    DatabaseMigrationHelper,
    ExternalLimitationToModify,
    LimitationToModify,
)

mh: DatabaseMigrationHelper

REVISION = "817bc761"
DOWN_REVISION = "b4b67753"


limitationsToModify: List[LimitationToModify] = []

externalLimitationsToModify: List[ExternalLimitationToModify] = []


def upgrade():
    """Upgrade configs to new revision"""

    # limitations to add
    mh.addLimitation(
        limitationName="LICENSE_VENDOR",
        validationSchema={
            "oneOf": [
                {
                    "type": "object",
                    "properties": {
                        "vendor": {"type": "string", "enum": ["hasp"]},
                        "server_address": {"type": "string"},
                    },
                    "additionalProperties": False,
                    "default": {"vendor": "hasp", "server_address": "127.0.0.1"},
                },
                {
                    "type": "object",
                    "properties": {
                        "vendor": {"type": "string", "enum": ["guardant"]},
                        "server_address": {"type": "string"},
                        "license_id": {"type": "string"},
                    },
                    "additionalProperties": False,
                    "default": {
                        "vendor": "hasp",
                        "server_address": "127.0.0.1",
                        "license_id": "1",
                    },
                },
            ]
        },
        defaultValue={"vendor": "hasp", "server_address": "127.0.0.1"},
        description="License vendor config",
        services=["luna-licenses"],
        groupNames=["luna-platform"],
    )

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)

    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)


def downgrade():
    """Downgrade configs to previous revision"""

    # limitations to modify
    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)

    # limitations to remove
    mh.removeLimitation(limitationName="LICENSE_VENDOR")
