"""
Configs migration

Generation datetime: 2022-08-15 12:31:49.517371
"""

from typing import List

from configs_core.migration.db_migrate_helper import DatabaseMigrationHelper, LimitationToModify

mh: DatabaseMigrationHelper

REVISION = "90c6a216"
DOWN_REVISION = "b039d1f9"


limitationsToModify: List[LimitationToModify] = [
    LimitationToModify(
        limitationName="LUNA_IMAGE_STORE_OBJECTS_ADDRESS",
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-api"],
        newServices=["luna-api", "luna-tasks"],
    ),
]


def upgrade():
    """Upgrade configs to new revision"""

    # limitations to add
    mh.addLimitation(
        limitationName="EXTERNAL_LUNA_API_ADDRESS",
        validationSchema={
            "type": "object",
            "properties": {
                "origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                },
                "api_version": {"type": "integer"},
            },
            "required": ["origin", "api_version"],
            "additionalProperties": False,
        },
        defaultValue={"origin": "http://127.0.0.1:5000", "api_version": 6},
        description="external luna api address",
        services=["luna-handlers", "luna-tasks"],
        groupNames=["luna-platform"],
    )

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)


def downgrade():
    """Downgrade configs to previous revision"""

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)

    # limitations to remove
    mh.removeLimitation(limitationName="EXTERNAL_LUNA_API_ADDRESS")
