"""
Configs migration

Generation datetime: 2023-03-16 12:59:52.873257
"""

from typing import List

from configs_core.migration.db_migrate_helper import (
    DatabaseMigrationHelper,
    ExternalLimitationToModify,
    LimitationToModify,
)

mh: DatabaseMigrationHelper

REVISION = "d893870e"
DOWN_REVISION = "817bc761"


limitationsToModify: List[LimitationToModify] = []

externalLimitationsToModify: List[ExternalLimitationToModify] = []


def upgrade():
    """Upgrade configs to new revision"""

    # groups to add
    mh.addGroup(groupName="http-settings", groupDescription="")

    # limitations to add
    mh.addLimitation(
        limitationName="LUNA_ACCOUNTS_HTTP_SETTINGS",
        validationSchema={
            "type": "object",
            "properties": {
                "request_timeout": {"type": "integer", "minimum": 1},
                "response_timeout": {"type": "integer", "minimum": 1},
                "request_max_size": {"type": "integer", "minimum": 1},
                "keep_alive_timeout": {"type": "integer", "minimum": 1},
            },
            "additionalProperties": False,
        },
        defaultValue={
            "request_timeout": 60,
            "response_timeout": 600,
            "request_max_size": 1073741824,
            "keep_alive_timeout": 200,
        },
        description="Luna Accounts http settings",
        services=["luna-accounts"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_ADMIN_HTTP_SETTINGS",
        validationSchema={
            "type": "object",
            "properties": {
                "request_timeout": {"type": "integer", "minimum": 1},
                "response_timeout": {"type": "integer", "minimum": 1},
                "request_max_size": {"type": "integer", "minimum": 1},
                "keep_alive_timeout": {"type": "integer", "minimum": 1},
            },
            "additionalProperties": False,
        },
        defaultValue={
            "request_timeout": 60,
            "response_timeout": 600,
            "request_max_size": 1073741824,
            "keep_alive_timeout": 200,
        },
        description="Luna Admin http settings",
        services=["luna-admin"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_API_HTTP_SETTINGS",
        validationSchema={
            "type": "object",
            "properties": {
                "request_timeout": {"type": "integer", "minimum": 1},
                "response_timeout": {"type": "integer", "minimum": 1},
                "request_max_size": {"type": "integer", "minimum": 1},
                "keep_alive_timeout": {"type": "integer", "minimum": 1},
            },
            "additionalProperties": False,
        },
        defaultValue={
            "request_timeout": 60,
            "response_timeout": 600,
            "request_max_size": 137438953472,
            "keep_alive_timeout": 15,
        },
        description="luna-api http settings",
        services=["luna-api"],
        groupNames=["luna-platform", "http-settings"],
    )
    mh.addLimitation(
        limitationName="LUNA_BACKPORT3_HTTP_SETTINGS",
        validationSchema={
            "type": "object",
            "properties": {
                "request_timeout": {"type": "integer", "minimum": 1},
                "response_timeout": {"type": "integer", "minimum": 1},
                "request_max_size": {"type": "integer", "minimum": 1},
                "keep_alive_timeout": {"type": "integer", "minimum": 1},
            },
            "additionalProperties": False,
        },
        defaultValue={
            "request_timeout": 60,
            "response_timeout": 600,
            "request_max_size": 1073741824,
            "keep_alive_timeout": 200,
        },
        description="Luna Backport3 http settings",
        services=["luna-backport3"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_BACKPORT4_HTTP_SETTINGS",
        validationSchema={
            "type": "object",
            "properties": {
                "request_timeout": {"type": "integer", "minimum": 1},
                "response_timeout": {"type": "integer", "minimum": 1},
                "request_max_size": {"type": "integer", "minimum": 1},
                "keep_alive_timeout": {"type": "integer", "minimum": 1},
            },
            "additionalProperties": False,
        },
        defaultValue={
            "request_timeout": 60,
            "response_timeout": 600,
            "request_max_size": 1073741824,
            "keep_alive_timeout": 200,
        },
        description="Luna Backport4 http settings",
        services=["luna-backport4"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_EVENTS_HTTP_SETTINGS",
        validationSchema={
            "type": "object",
            "properties": {
                "request_timeout": {"type": "integer", "minimum": 1},
                "response_timeout": {"type": "integer", "minimum": 1},
                "request_max_size": {"type": "integer", "minimum": 1},
                "keep_alive_timeout": {"type": "integer", "minimum": 1},
            },
            "additionalProperties": False,
        },
        defaultValue={
            "request_timeout": 60,
            "response_timeout": 600,
            "request_max_size": 1073741824,
            "keep_alive_timeout": 200,
        },
        description="Luna Events http settings",
        services=["luna-events"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_FACES_HTTP_SETTINGS",
        validationSchema={
            "type": "object",
            "properties": {
                "request_timeout": {"type": "integer", "minimum": 1},
                "response_timeout": {"type": "integer", "minimum": 1},
                "request_max_size": {"type": "integer", "minimum": 1},
                "keep_alive_timeout": {"type": "integer", "minimum": 1},
            },
            "additionalProperties": False,
        },
        defaultValue={
            "request_timeout": 60,
            "response_timeout": 600,
            "request_max_size": 1073741824,
            "keep_alive_timeout": 200,
        },
        description="Luna Faces http settings",
        services=["luna-faces"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_HANDLERS_HTTP_SETTINGS",
        validationSchema={
            "type": "object",
            "properties": {
                "request_timeout": {"type": "integer", "minimum": 1},
                "response_timeout": {"type": "integer", "minimum": 1},
                "request_max_size": {"type": "integer", "minimum": 1},
                "keep_alive_timeout": {"type": "integer", "minimum": 1},
            },
            "additionalProperties": False,
        },
        defaultValue={
            "request_timeout": 60,
            "response_timeout": 600,
            "request_max_size": 1073741824,
            "keep_alive_timeout": 200,
        },
        description="Luna Handlers http settings",
        services=["luna-handlers"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_IMAGE_STORE_HTTP_SETTINGS",
        validationSchema={
            "type": "object",
            "properties": {
                "request_timeout": {"type": "integer", "minimum": 1},
                "response_timeout": {"type": "integer", "minimum": 1},
                "request_max_size": {"type": "integer", "minimum": 1},
                "keep_alive_timeout": {"type": "integer", "minimum": 1},
            },
            "additionalProperties": False,
        },
        defaultValue={
            "request_timeout": 60,
            "response_timeout": 600,
            "request_max_size": 137438953472,
            "keep_alive_timeout": 200,
        },
        description="luna-image-store http settings",
        services=["luna-image-store"],
        groupNames=["luna-platform", "http-settings"],
    )
    mh.addLimitation(
        limitationName="LUNA_LICENSES_HTTP_SETTINGS",
        validationSchema={
            "type": "object",
            "properties": {
                "request_timeout": {"type": "integer", "minimum": 1},
                "response_timeout": {"type": "integer", "minimum": 1},
                "request_max_size": {"type": "integer", "minimum": 1},
                "keep_alive_timeout": {"type": "integer", "minimum": 1},
            },
            "additionalProperties": False,
        },
        defaultValue={
            "request_timeout": 60,
            "response_timeout": 600,
            "request_max_size": 1073741824,
            "keep_alive_timeout": 200,
        },
        description="Luna Licenses http settings",
        services=["luna-licenses"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_MATCHER_PROXY_HTTP_SETTINGS",
        validationSchema={
            "type": "object",
            "properties": {
                "request_timeout": {"type": "integer", "minimum": 1},
                "response_timeout": {"type": "integer", "minimum": 1},
                "request_max_size": {"type": "integer", "minimum": 1},
                "keep_alive_timeout": {"type": "integer", "minimum": 1},
            },
            "additionalProperties": False,
        },
        defaultValue={
            "request_timeout": 60,
            "response_timeout": 600,
            "request_max_size": 1073741824,
            "keep_alive_timeout": 200,
        },
        description="Luna Matcher Proxy http settings",
        services=["luna-matcher-proxy"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_PYTHON_MATCHER_HTTP_SETTINGS",
        validationSchema={
            "type": "object",
            "properties": {
                "request_timeout": {"type": "integer", "minimum": 1},
                "response_timeout": {"type": "integer", "minimum": 1},
                "request_max_size": {"type": "integer", "minimum": 1},
                "keep_alive_timeout": {"type": "integer", "minimum": 1},
            },
            "additionalProperties": False,
        },
        defaultValue={
            "request_timeout": 60,
            "response_timeout": 600,
            "request_max_size": 1073741824,
            "keep_alive_timeout": 200,
        },
        description="Luna Python Matcher http settings",
        services=["luna-python-matcher"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_SENDER_HTTP_SETTINGS",
        validationSchema={
            "type": "object",
            "properties": {
                "request_timeout": {"type": "integer", "minimum": 1},
                "response_timeout": {"type": "integer", "minimum": 1},
                "request_max_size": {"type": "integer", "minimum": 1},
                "keep_alive_timeout": {"type": "integer", "minimum": 1},
            },
            "additionalProperties": False,
        },
        defaultValue={
            "request_timeout": 60,
            "response_timeout": 600,
            "request_max_size": 1073741824,
            "keep_alive_timeout": 200,
        },
        description="Luna Sender http settings",
        services=["luna-sender"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_TASKS_HTTP_SETTINGS",
        validationSchema={
            "type": "object",
            "properties": {
                "request_timeout": {"type": "integer", "minimum": 1},
                "response_timeout": {"type": "integer", "minimum": 1},
                "request_max_size": {"type": "integer", "minimum": 1},
                "keep_alive_timeout": {"type": "integer", "minimum": 1},
            },
            "additionalProperties": False,
        },
        defaultValue={
            "request_timeout": 60,
            "response_timeout": 600,
            "request_max_size": 1073741824,
            "keep_alive_timeout": 200,
        },
        description="Luna Tasks http settings",
        services=["luna-tasks"],
        groupNames=["luna-platform"],
    )

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)

    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)


def downgrade():
    """Downgrade configs to previous revision"""

    # limitations to modify
    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)

    # limitations to remove
    mh.removeLimitation(limitationName="LUNA_ACCOUNTS_HTTP_SETTINGS")
    mh.removeLimitation(limitationName="LUNA_ADMIN_HTTP_SETTINGS")
    mh.removeLimitation(limitationName="LUNA_API_HTTP_SETTINGS")
    mh.removeLimitation(limitationName="LUNA_BACKPORT3_HTTP_SETTINGS")
    mh.removeLimitation(limitationName="LUNA_BACKPORT4_HTTP_SETTINGS")
    mh.removeLimitation(limitationName="LUNA_EVENTS_HTTP_SETTINGS")
    mh.removeLimitation(limitationName="LUNA_FACES_HTTP_SETTINGS")
    mh.removeLimitation(limitationName="LUNA_HANDLERS_HTTP_SETTINGS")
    mh.removeLimitation(limitationName="LUNA_IMAGE_STORE_HTTP_SETTINGS")
    mh.removeLimitation(limitationName="LUNA_LICENSES_HTTP_SETTINGS")
    mh.removeLimitation(limitationName="LUNA_MATCHER_PROXY_HTTP_SETTINGS")
    mh.removeLimitation(limitationName="LUNA_PYTHON_MATCHER_HTTP_SETTINGS")
    mh.removeLimitation(limitationName="LUNA_SENDER_HTTP_SETTINGS")
    mh.removeLimitation(limitationName="LUNA_TASKS_HTTP_SETTINGS")

    # groups to remove
    mh.removeGroup(groupName="http-settings")
