"""
Configs migration

Generation datetime: 2023-07-07 05:57:43.641706
"""

from typing import List

from configs_core.migration.db_migrate_helper import (
    DatabaseMigrationHelper,
    ExternalLimitationToModify,
    LimitationToModify,
)

mh: DatabaseMigrationHelper

REVISION = "c0e7b9e0"
DOWN_REVISION = "7708128b"


limitationsToModify: List[LimitationToModify] = []

externalLimitationsToModify: List[ExternalLimitationToModify] = []


def upgrade():
    """Upgrade configs to new revision"""

    # limitations to add
    mh.addLimitation(
        limitationName="LUNA_REMOTE_SDK_TIMEOUTS",
        validationSchema={
            "type": "object",
            "properties": {
                "request": {"type": "number", "exclusiveMinimum": 0},
                "connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_read": {"type": "number", "exclusiveMinimum": 0},
            },
            "description": "timeouts in seconds",
            "additionalProperties": False,
        },
        defaultValue={
            "request": 60,
            "connect": 20,
            "sock_connect": 10,
            "sock_read": 60,
        },
        description="timeouts for http-request to luna-remote-sdk service",
        services=["luna-api", "luna-handlers"],
        groupNames=["luna-platform"],
    )

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)

    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)


def downgrade():
    """Downgrade configs to previous revision"""

    # limitations to modify
    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)

    # limitations to remove
    mh.removeLimitation(limitationName="LUNA_REMOTE_SDK_TIMEOUTS")
