"""
Configs migration

Generation datetime: 2023-10-10 20:35:27.985342
"""

from typing import List

from configs_core.migration.db_migrate_helper import (
    DatabaseMigrationHelper,
    ExternalLimitationToModify,
    LimitationToModify,
)

mh: DatabaseMigrationHelper

REVISION = "33868d03"
DOWN_REVISION = "931989a8"


limitationsToModify: List[LimitationToModify] = []

externalLimitationsToModify: List[ExternalLimitationToModify] = []


def upgrade():
    """Upgrade configs to new revision"""

    # limitations to add
    mh.addLimitation(
        limitationName="LUNA_REMOTE_SDK_DEEPFAKE_ESTIMATOR_SETTINGS",
        validationSchema={
            "type": "object",
            "properties": {
                "runtime_settings": {
                    "type": "object",
                    "properties": {
                        "device_class": {
                            "type": "string",
                            "enum": ["global", "cpu", "gpu"],
                        },
                        "optimal_batch_size": {"type": "integer", "minimum": 1},
                        "worker_count": {"type": "integer", "minimum": 1},
                    },
                    "additionalProperties": False,
                },
                "estimator_settings": {
                    "type": "object",
                    "properties": {
                        "real_threshold": {
                            "type": "number",
                            "minimum": 0,
                            "maximum": 1,
                        },
                        "estimation_mode": {"type": "integer", "enum": [1, 2]},
                    },
                    "description": "FSDK deepfake estimator settings",
                    "additionalProperties": False,
                },
            },
            "description": "settings for sdk deepfake estimator",
            "additionalProperties": False,
        },
        defaultValue={
            "runtime_settings": {
                "device_class": "global",
                "optimal_batch_size": 10,
                "worker_count": 1,
            },
            "estimator_settings": {"real_threshold": 0.5, "estimation_mode": 2},
        },
        description="luna-remote-sdk settings for liveness estimation in handlers",
        services=["luna-remote-sdk"],
        groupNames=["luna-platform", "luna-handlers-estimators-settings"],
    )

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)

    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)


def downgrade():
    """Downgrade configs to previous revision"""

    # limitations to modify
    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)

    # limitations to remove
    mh.removeLimitation(limitationName="LUNA_REMOTE_SDK_DEEPFAKE_ESTIMATOR_SETTINGS")
