"""
Configs migration

Generation datetime: 2024-02-02 15:52:50.701483
"""

from configs_core.migration.db_migrate_helper import (
    DatabaseMigrationHelper,
    ExternalLimitationToModify,
    LimitationToModify,
)

mh: DatabaseMigrationHelper

REVISION = "c40cf267"
DOWN_REVISION = "6a3d8839"


limitationsToModify: list[LimitationToModify] = []

externalLimitationsToModify: list[ExternalLimitationToModify] = []


def upgrade():
    """Upgrade configs to new revision"""

    # limitations to add
    mh.addLimitation(
        limitationName="LUNA_SERVICE_METRICS",
        validationSchema={
            "type": "object",
            "properties": {
                "enabled": {"type": "boolean"},
                "metrics_format": {"type": "string"},
                "extra_labels": {
                    "type": "object",
                    "properties": {},
                    "additionalProperties": True,
                },
            },
            "additionalProperties": False,
        },
        defaultValue={
            "enabled": False,
            "metrics_format": "prometheus",
            "extra_labels": {},
        },
        description="Metrics collection configuration",
        services=[
            "luna-accounts",
            "luna-admin",
            "luna-api",
            "luna-backport3",
            "luna-backport4",
            "luna-events",
            "luna-faces",
            "luna-handlers",
            "luna-image-store",
            "luna-lambda",
            "luna-lambda-tasks-unit",
            "luna-lambda-unit",
            "luna-licenses",
            "luna-matcher-proxy",
            "luna-python-matcher",
            "luna-remote-sdk",
            "luna-sender",
            "luna-tasks",
        ],
        groupNames=["luna-platform"],
    )

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)

    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)


def downgrade():
    """Downgrade configs to previous revision"""

    # limitations to modify
    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)

    # limitations to remove
    mh.removeLimitation(limitationName="LUNA_SERVICE_METRICS")
