"""
Configs migration

Generation datetime: 2024-04-03 08:50:26.515951
"""

from configs_core.migration.db_migrate_helper import (
    DatabaseMigrationHelper,
    ExternalLimitationToModify,
    LimitationToModify,
)

mh: DatabaseMigrationHelper

REVISION = "614fd8ec"
DOWN_REVISION = "636532ad"


def upgradeASUDBSetting(setting: dict) -> dict:
    """Upgrade ASU setting."""
    setting["luna_video_manager"] = False
    return setting


def downgradeASUDBSetting(setting: dict) -> dict:
    """Downgrade ASU setting."""
    setting.pop("luna_video_manager", None)
    return setting


limitationsToModify: list[LimitationToModify] = [
    LimitationToModify(
        limitationName="LUNA_SERVICE_METRICS",
        oldValidationSchema={
            "type": "object",
            "properties": {
                "enabled": {"type": "boolean"},
                "metrics_format": {"type": "string"},
                "extra_labels": {
                    "type": "object",
                    "properties": {},
                    "additionalProperties": True,
                },
            },
            "additionalProperties": False,
        },
        newValidationSchema={
            "type": "object",
            "properties": {
                "enabled": {"type": "boolean"},
                "metrics_format": {"type": "string"},
                "extra_labels": {
                    "type": "object",
                    "properties": {},
                    "additionalProperties": True,
                },
            },
            "additionalProperties": False,
        },
        oldDefaultValue={
            "enabled": False,
            "metrics_format": "prometheus",
            "extra_labels": {},
        },
        newDefaultValue={
            "enabled": False,
            "metrics_format": "prometheus",
            "extra_labels": {},
        },
        oldDescription="Metrics collection configuration",
        newDescription="Metrics collection configuration",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=[
            "luna-accounts",
            "luna-admin",
            "luna-api",
            "luna-backport3",
            "luna-backport4",
            "luna-events",
            "luna-faces",
            "luna-handlers",
            "luna-image-store",
            "luna-lambda",
            "luna-lambda-tasks-unit",
            "luna-lambda-unit",
            "luna-licenses",
            "luna-matcher-proxy",
            "luna-python-matcher",
            "luna-remote-sdk",
            "luna-sender",
            "luna-tasks",
        ],
        newServices=[
            "luna-accounts",
            "luna-admin",
            "luna-api",
            "luna-backport3",
            "luna-backport4",
            "luna-events",
            "luna-faces",
            "luna-handlers",
            "luna-image-store",
            "luna-lambda",
            "luna-lambda-tasks-unit",
            "luna-lambda-unit",
            "luna-licenses",
            "luna-matcher-proxy",
            "luna-python-matcher",
            "luna-remote-sdk",
            "luna-sender",
            "luna-tasks",
            "luna-video-agent",
            "luna-video-manager",
        ],
    ),
    LimitationToModify(
        limitationName="INFLUX_MONITORING",
        oldValidationSchema={
            "properties": {
                "send_data_for_monitoring": {"type": "integer", "enum": [0, 1]},
                "use_ssl": {"type": "integer", "enum": [0, 1]},
                "flushing_period": {"type": "number"},
                "host": {"type": "string"},
                "port": {"type": "integer", "minimum": 1, "maximum": 65535},
                "organization": {"type": "string"},
                "token": {"type": "string"},
                "bucket": {"type": "string"},
            },
            "default": {
                "send_data_for_monitoring": 1,
                "use_ssl": 0,
                "flushing_period": 1,
                "host": "127.0.0.1",
                "port": 8086,
                "organization": "luna",
                "token": "secret-token",
                "bucket": "luna_monitoring",
            },
            "required": [
                "send_data_for_monitoring",
                "host",
                "port",
                "organization",
                "token",
                "bucket",
            ],
            "type": "object",
            "additionalProperties": False,
            "description": "Monitoring settings.",
        },
        newValidationSchema={
            "properties": {
                "send_data_for_monitoring": {"type": "integer", "enum": [0, 1]},
                "use_ssl": {"type": "integer", "enum": [0, 1]},
                "flushing_period": {"type": "number"},
                "host": {"type": "string"},
                "port": {"type": "integer", "minimum": 1, "maximum": 65535},
                "organization": {"type": "string"},
                "token": {"type": "string"},
                "bucket": {"type": "string"},
            },
            "default": {
                "send_data_for_monitoring": 1,
                "use_ssl": 0,
                "flushing_period": 1,
                "host": "127.0.0.1",
                "port": 8086,
                "organization": "luna",
                "token": "secret-token",
                "bucket": "luna_monitoring",
            },
            "required": [
                "send_data_for_monitoring",
                "host",
                "port",
                "organization",
                "token",
                "bucket",
            ],
            "type": "object",
            "additionalProperties": False,
            "description": "Monitoring settings.",
        },
        oldDefaultValue={
            "send_data_for_monitoring": 1,
            "use_ssl": 0,
            "flushing_period": 1,
            "host": "127.0.0.1",
            "port": 8086,
            "bucket": "luna_monitoring",
            "organization": "luna",
            "token": "secret-token",
        },
        newDefaultValue={
            "send_data_for_monitoring": 1,
            "use_ssl": 0,
            "flushing_period": 1,
            "host": "127.0.0.1",
            "port": 8086,
            "bucket": "luna_monitoring",
            "organization": "luna",
            "token": "secret-token",
        },
        oldDescription="monitoring parameters",
        newDescription="monitoring parameters",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=[
            "luna-accounts",
            "luna-admin",
            "luna-api",
            "luna-backport3",
            "luna-backport4",
            "luna-events",
            "luna-faces",
            "luna-handlers",
            "luna-image-store",
            "luna-lambda",
            "luna-lambda-tasks-unit",
            "luna-lambda-unit",
            "luna-licenses",
            "luna-matcher-proxy",
            "luna-python-matcher",
            "luna-remote-sdk",
            "luna-sender",
            "luna-tasks",
        ],
        newServices=[
            "luna-accounts",
            "luna-admin",
            "luna-api",
            "luna-backport3",
            "luna-backport4",
            "luna-events",
            "luna-faces",
            "luna-handlers",
            "luna-image-store",
            "luna-lambda",
            "luna-lambda-tasks-unit",
            "luna-lambda-unit",
            "luna-licenses",
            "luna-matcher-proxy",
            "luna-python-matcher",
            "luna-remote-sdk",
            "luna-sender",
            "luna-tasks",
            "luna-video-agent",
            "luna-video-manager",
        ],
    ),
    LimitationToModify(
        limitationName="STORAGE_TIME",
        oldValidationSchema={"type": "string", "enum": ["LOCAL", "UTC"]},
        newValidationSchema={"type": "string", "enum": ["LOCAL", "UTC"]},
        oldDefaultValue="LOCAL",
        newDefaultValue="LOCAL",
        oldDescription="Time in which records are stored in the database",
        newDescription="Time in which records are stored in the database",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=[
            "luna-accounts",
            "luna-backport3",
            "luna-events",
            "luna-faces",
            "luna-handlers",
            "luna-lambda",
            "luna-matcher-proxy",
            "luna-python-matcher",
            "luna-tasks",
        ],
        newServices=[
            "luna-accounts",
            "luna-backport3",
            "luna-events",
            "luna-faces",
            "luna-handlers",
            "luna-lambda",
            "luna-matcher-proxy",
            "luna-python-matcher",
            "luna-tasks",
            "luna-video-manager",
        ],
    ),
    LimitationToModify(
        limitationName="LUNA_LICENSES_ADDRESS",
        oldValidationSchema={
            "type": "object",
            "properties": {
                "origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                },
                "api_version": {"type": "integer"},
            },
            "required": ["origin", "api_version"],
            "additionalProperties": False,
        },
        newValidationSchema={
            "type": "object",
            "properties": {
                "origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                },
                "api_version": {"type": "integer"},
            },
            "required": ["origin", "api_version"],
            "additionalProperties": False,
        },
        oldDefaultValue={"origin": "http://127.0.0.1:5120", "api_version": 1},
        newDefaultValue={"origin": "http://127.0.0.1:5120", "api_version": 1},
        oldDescription="LUNA Licenses address",
        newDescription="LUNA Licenses address",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=[
            "luna-admin",
            "luna-api",
            "luna-faces",
            "luna-lambda",
            "luna-remote-sdk",
        ],
        newServices=[
            "luna-admin",
            "luna-api",
            "luna-faces",
            "luna-lambda",
            "luna-remote-sdk",
            "luna-video-agent",
        ],
    ),
    LimitationToModify(
        limitationName="LUNA_IMAGE_STORE_IMAGES_ADDRESS",
        oldValidationSchema={
            "type": "object",
            "properties": {
                "origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                },
                "api_version": {"type": "integer"},
                "bucket": {"type": "string"},
            },
            "required": ["origin", "api_version", "bucket"],
            "additionalProperties": False,
        },
        newValidationSchema={
            "type": "object",
            "properties": {
                "origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                },
                "api_version": {"type": "integer"},
                "bucket": {"type": "string"},
            },
            "required": ["origin", "api_version", "bucket"],
            "additionalProperties": False,
        },
        oldDefaultValue={
            "origin": "http://127.0.0.1:5020",
            "api_version": 1,
            "bucket": "visionlabs-image-origin",
        },
        newDefaultValue={
            "origin": "http://127.0.0.1:5020",
            "api_version": 1,
            "bucket": "visionlabs-image-origin",
        },
        oldDescription="Address of service for storing origin images",
        newDescription="Address of service for storing origin images",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=[
            "luna-admin",
            "luna-api",
            "luna-handlers",
            "luna-lambda-tasks-unit",
            "luna-lambda-unit",
            "luna-remote-sdk",
            "luna-tasks",
        ],
        newServices=[
            "luna-admin",
            "luna-api",
            "luna-handlers",
            "luna-lambda-tasks-unit",
            "luna-lambda-unit",
            "luna-remote-sdk",
            "luna-tasks",
            "luna-video-agent",
        ],
    ),
    LimitationToModify(
        limitationName="LUNA_IMAGE_STORE_IMAGES_TIMEOUTS",
        oldValidationSchema={
            "type": "object",
            "properties": {
                "request": {"type": "number", "exclusiveMinimum": 0},
                "connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_read": {"type": "number", "exclusiveMinimum": 0},
            },
            "description": "timeouts in seconds",
            "additionalProperties": False,
        },
        newValidationSchema={
            "type": "object",
            "properties": {
                "request": {"type": "number", "exclusiveMinimum": 0},
                "connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_read": {"type": "number", "exclusiveMinimum": 0},
            },
            "description": "timeouts in seconds",
            "additionalProperties": False,
        },
        oldDefaultValue={
            "request": 60,
            "connect": 20,
            "sock_connect": 10,
            "sock_read": 60,
        },
        newDefaultValue={
            "request": 60,
            "connect": 20,
            "sock_connect": 10,
            "sock_read": 60,
        },
        oldDescription="timeouts for http-request to luna-image-store service",
        newDescription="timeouts for http-request to luna-image-store service",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=[
            "luna-api",
            "luna-handlers",
            "luna-lambda-tasks-unit",
            "luna-lambda-unit",
            "luna-remote-sdk",
            "luna-tasks",
        ],
        newServices=[
            "luna-api",
            "luna-handlers",
            "luna-lambda-tasks-unit",
            "luna-lambda-unit",
            "luna-remote-sdk",
            "luna-tasks",
            "luna-video-agent",
        ],
    ),
    LimitationToModify(
        limitationName="ADDITIONAL_SERVICES_USAGE",
        oldValidationSchema={
            "type": "object",
            "properties": {
                "luna_sender": {"type": "boolean"},
                "luna_events": {"type": "boolean"},
                "luna_tasks": {"type": "boolean"},
                "luna_matcher_proxy": {"type": "boolean"},
                "luna_image_store": {"type": "boolean"},
                "luna_handlers": {"type": "boolean"},
                "luna_lambda": {"type": "boolean"},
            },
            "required": [
                "luna_sender",
                "luna_events",
                "luna_tasks",
                "luna_matcher_proxy",
                "luna_image_store",
                "luna_handlers",
                "luna_lambda",
            ],
            "description": "whether to use nested optional services",
            "additionalProperties": False,
        },
        newValidationSchema={
            "type": "object",
            "properties": {
                "luna_sender": {"type": "boolean"},
                "luna_events": {"type": "boolean"},
                "luna_tasks": {"type": "boolean"},
                "luna_matcher_proxy": {"type": "boolean"},
                "luna_image_store": {"type": "boolean"},
                "luna_handlers": {"type": "boolean"},
                "luna_lambda": {"type": "boolean"},
                "luna_video_manager": {"type": "boolean"},
            },
            "required": [
                "luna_sender",
                "luna_events",
                "luna_tasks",
                "luna_matcher_proxy",
                "luna_image_store",
                "luna_handlers",
                "luna_lambda",
                "luna_video_manager",
            ],
            "description": "whether to use nested optional services",
            "additionalProperties": False,
        },
        oldDefaultValue={
            "luna_sender": True,
            "luna_events": True,
            "luna_tasks": True,
            "luna_matcher_proxy": False,
            "luna_image_store": True,
            "luna_handlers": True,
            "luna_lambda": False,
        },
        newDefaultValue={
            "luna_sender": True,
            "luna_events": True,
            "luna_tasks": True,
            "luna_matcher_proxy": False,
            "luna_image_store": True,
            "luna_handlers": True,
            "luna_lambda": False,
            "luna_video_manager": False,
        },
        oldDescription="whether to use nested optional services",
        newDescription="whether to use nested optional services",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=upgradeASUDBSetting,
        settingDowngradeFunction=downgradeASUDBSetting,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=[
            "luna-admin",
            "luna-api",
            "luna-handlers",
            "luna-lambda",
            "luna-lambda-tasks-unit",
            "luna-lambda-unit",
            "luna-matcher-proxy",
            "luna-python-matcher",
            "luna-remote-sdk",
            "luna-tasks",
        ],
        newServices=[
            "luna-admin",
            "luna-api",
            "luna-handlers",
            "luna-lambda",
            "luna-lambda-tasks-unit",
            "luna-lambda-unit",
            "luna-matcher-proxy",
            "luna-python-matcher",
            "luna-remote-sdk",
            "luna-tasks",
            "luna-video-agent",
        ],
    ),
    LimitationToModify(
        limitationName="EXTERNAL_LUNA_API_ADDRESS",
        oldValidationSchema={
            "type": "object",
            "properties": {
                "origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                },
                "api_version": {"type": "integer"},
            },
            "required": ["origin", "api_version"],
            "additionalProperties": False,
        },
        newValidationSchema={
            "type": "object",
            "properties": {
                "origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                },
                "api_version": {"type": "integer"},
            },
            "required": ["origin", "api_version"],
            "additionalProperties": False,
        },
        oldDefaultValue={"origin": "http://127.0.0.1:5000", "api_version": 6},
        newDefaultValue={"origin": "http://127.0.0.1:5000", "api_version": 6},
        oldDescription="external luna api address",
        newDescription="external luna api address",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=[
            "luna-api",
            "luna-handlers",
            "luna-lambda-tasks-unit",
            "luna-remote-sdk",
            "luna-tasks",
        ],
        newServices=[
            "luna-api",
            "luna-handlers",
            "luna-lambda-tasks-unit",
            "luna-remote-sdk",
            "luna-tasks",
            "luna-video-agent",
        ],
    ),
    LimitationToModify(
        limitationName="LUNA_SENDER_ADDRESS",
        oldValidationSchema={
            "type": "object",
            "properties": {
                "origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                },
                "api_version": {"type": "integer"},
            },
            "required": ["origin", "api_version"],
            "additionalProperties": False,
        },
        newValidationSchema={
            "type": "object",
            "properties": {
                "origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                },
                "api_version": {"type": "integer"},
            },
            "required": ["origin", "api_version"],
            "additionalProperties": False,
        },
        oldDefaultValue={"origin": "http://127.0.0.1:5080", "api_version": 2},
        newDefaultValue={"origin": "http://127.0.0.1:5080", "api_version": 2},
        oldDescription="LUNA Sender address",
        newDescription="LUNA Sender address",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=[
            "luna-admin",
            "luna-api",
            "luna-lambda-tasks-unit",
            "luna-lambda-unit",
        ],
        newServices=[
            "luna-admin",
            "luna-api",
            "luna-lambda-tasks-unit",
            "luna-lambda-unit",
            "luna-video-agent",
        ],
    ),
]

externalLimitationsToModify: list[ExternalLimitationToModify] = []


def upgrade():
    """Upgrade configs to new revision"""

    # limitations to add
    mh.addLimitation(
        limitationName="LUNA_VIDEO_MANAGER_ACTIVE_PLUGINS",
        validationSchema={"type": "array", "items": {"type": "string"}},
        defaultValue=[],
        description="list of luna-video-manager active plugins",
        services=["luna-video-manager"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_VIDEO_MANAGER_HTTP_SETTINGS",
        validationSchema={
            "type": "object",
            "properties": {
                "request_timeout": {"type": "integer", "minimum": 1},
                "response_timeout": {"type": "integer", "minimum": 1},
                "request_max_size": {"type": "integer", "minimum": 1},
                "keep_alive_timeout": {"type": "integer", "minimum": 1},
            },
            "additionalProperties": False,
        },
        defaultValue={
            "request_timeout": 60,
            "response_timeout": 600,
            "request_max_size": 1073741824,
            "keep_alive_timeout": 200,
        },
        description="Luna Video Manager http settings",
        services=["luna-video-manager"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_VIDEO_MANAGER_LOGGER",
        validationSchema={
            "type": "object",
            "properties": {
                "log_level": {
                    "type": "string",
                    "enum": ["ERROR", "WARNING", "INFO", "DEBUG"],
                },
                "folder_with_logs": {"type": "string"},
                "max_log_file_size": {"type": "integer"},
                "log_time": {"type": "string", "enum": ["LOCAL", "UTC"]},
                "log_to_stdout": {"type": "boolean"},
                "log_to_file": {"type": "boolean"},
                "multiline_stack_trace": {"type": "boolean"},
                "format": {"type": "string", "enum": ["default", "json", "ecs"]},
            },
            "additionalProperties": False,
        },
        defaultValue={
            "log_level": "INFO",
            "folder_with_logs": "./",
            "max_log_file_size": 1024,
            "log_time": "LOCAL",
            "log_to_stdout": True,
            "log_to_file": False,
            "multiline_stack_trace": True,
            "format": "default",
        },
        description="Luna Video Manager logger settings",
        services=["luna-video-manager"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_VIDEO_MANAGER_DB",
        validationSchema={
            "properties": {
                "db_type": {"type": "string", "enum": ["postgres", "oracle"]},
                "dsn": {
                    "type": "string",
                    "pattern": "^(?:(?P<user>.*?)(?::(?P<passwd>.*))@)?(?P<net>[^\\?\\/]*)(?:\\/(?P<dbname>[^\\?]*)(?:\\?(?P<params>[^\\?]*))?)?$",
                },
                "db_user": {"type": "string"},
                "db_password": {"type": "string"},
                "db_name": {"type": "string"},
                "db_host": {"type": "string"},
                "db_port": {"type": "integer", "minimum": 1, "maximum": 65535},
                "db_settings": {
                    "type": "object",
                    "properties": {"connection_pool_size": {"type": "integer", "minimum": 1}},
                    "required": ["connection_pool_size"],
                    "additionalProperties": False,
                },
            },
            "required": ["db_type", "db_settings"],
            "type": "object",
            "additionalProperties": False,
        },
        defaultValue={
            "db_type": "postgres",
            "db_user": "luna",
            "db_password": "luna",
            "db_name": "luna_video_manager",
            "db_host": "127.0.0.1",
            "db_port": 5432,
            "db_settings": {"connection_pool_size": 5},
        },
        description="Main database for luna-video-manager service",
        services=["luna-video-manager"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_VIDEO_MANAGER_STREAM_STATUS_OBSOLETING_PERIOD",
        validationSchema={"type": "number", "exclusiveMinimum": 0, "maximum": 86400},
        defaultValue=20,
        description="video manager stream status obsoleting period, sec",
        services=["luna-video-manager"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_VIDEO_AGENT_ACTIVE_PLUGINS",
        validationSchema={"type": "array", "items": {"type": "string"}},
        defaultValue=[],
        description="list of luna-video-agent active plugins",
        services=["luna-video-agent"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_VIDEO_AGENT_HTTP_SETTINGS",
        validationSchema={
            "type": "object",
            "properties": {
                "request_timeout": {"type": "integer", "minimum": 1},
                "response_timeout": {"type": "integer", "minimum": 1},
                "request_max_size": {"type": "integer", "minimum": 1},
                "keep_alive_timeout": {"type": "integer", "minimum": 1},
            },
            "additionalProperties": False,
        },
        defaultValue={
            "request_timeout": 60,
            "response_timeout": 600,
            "request_max_size": 1073741824,
            "keep_alive_timeout": 200,
        },
        description="Luna Video Agent http settings",
        services=["luna-video-agent"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_VIDEO_AGENT_LOGGER",
        validationSchema={
            "type": "object",
            "properties": {
                "log_level": {
                    "type": "string",
                    "enum": ["ERROR", "WARNING", "INFO", "DEBUG"],
                },
                "folder_with_logs": {"type": "string"},
                "max_log_file_size": {"type": "integer"},
                "log_time": {"type": "string", "enum": ["LOCAL", "UTC"]},
                "log_to_stdout": {"type": "boolean"},
                "log_to_file": {"type": "boolean"},
                "multiline_stack_trace": {"type": "boolean"},
                "format": {"type": "string", "enum": ["default", "json", "ecs"]},
            },
            "additionalProperties": False,
        },
        defaultValue={
            "log_level": "INFO",
            "folder_with_logs": "./",
            "max_log_file_size": 1024,
            "log_time": "LOCAL",
            "log_to_stdout": True,
            "log_to_file": False,
            "multiline_stack_trace": True,
            "format": "default",
        },
        description="Luna Video Agent logger settings",
        services=["luna-video-agent"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_VIDEO_AGENT_RUNTIME_SETTINGS",
        validationSchema={
            "type": "object",
            "properties": {
                "global_device_class": {"type": "string", "enum": ["cpu", "gpu"]},
                "num_threads": {"type": "integer", "minimum": 1},
                "num_compute_streams": {"type": "integer", "minimum": 1},
            },
            "description": "sdk runtime settings",
            "additionalProperties": False,
        },
        defaultValue={
            "global_device_class": "cpu",
            "num_threads": 6,
            "num_compute_streams": 4,
        },
        description="runtime settings for luna-video-agent",
        services=["luna-video-agent"],
        groupNames=["luna-platform", "luna-handlers-estimators-settings"],
    )
    mh.addLimitation(
        limitationName="LUNA_VIDEO_AGENT_VIDEO_SETTINGS",
        validationSchema={
            "type": "object",
            "properties": {
                "decoder_device_class": {
                    "type": "string",
                    "enum": ["cpu", "gpu", "auto"],
                },
                "decoder_worker_count": {"type": "integer", "minimum": 1},
                "max_size": {"type": "integer", "minimum": 1},
            },
            "description": "video processing settings",
            "additionalProperties": False,
        },
        defaultValue={
            "decoder_device_class": "auto",
            "decoder_worker_count": 10,
            "max_size": 2048,
        },
        description="luna-video-agent video processing settings",
        services=["luna-video-agent"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_VIDEO_MANAGER_ADDRESS",
        validationSchema={
            "type": "object",
            "properties": {
                "origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                },
                "api_version": {"type": "integer"},
            },
            "required": ["origin", "api_version"],
            "additionalProperties": False,
        },
        defaultValue={"origin": "http://127.0.0.1:5230", "api_version": 1},
        description="LUNA Video manager address",
        services=["luna-video-agent", "luna-api", "luna-admin"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_VIDEO_MANAGER_TIMEOUTS",
        validationSchema={
            "type": "object",
            "properties": {
                "request": {"type": "number", "exclusiveMinimum": 0},
                "connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_read": {"type": "number", "exclusiveMinimum": 0},
            },
            "description": "timeouts in seconds",
            "additionalProperties": False,
        },
        defaultValue={
            "request": 60,
            "connect": 20,
            "sock_connect": 10,
            "sock_read": 60,
        },
        description="timeouts for http-request to luna-video-manager service",
        services=["luna-video-agent", "luna-api"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_VIDEO_AGENT_PEOPLE_COUNT_ESTIMATOR_SETTINGS",
        validationSchema={
            "type": "object",
            "properties": {
                "runtime_settings": {
                    "type": "object",
                    "properties": {
                        "device_class": {
                            "type": "string",
                            "enum": ["global", "cpu", "gpu"],
                        },
                        "optimal_batch_size": {"type": "integer", "minimum": 1},
                        "worker_count": {"type": "integer", "minimum": 1},
                    },
                    "additionalProperties": False,
                }
            },
            "description": "settings for sdk estimator",
            "additionalProperties": False,
        },
        defaultValue={
            "runtime_settings": {
                "device_class": "global",
                "optimal_batch_size": 10,
                "worker_count": 1,
            }
        },
        description="luna-video-agent settings for people count estimation",
        services=["luna-video-agent"],
        groupNames=["luna-platform", "luna-handlers-estimators-settings"],
    )
    mh.addLimitation(
        limitationName="LUNA_VIDEO_MANAGER_AGENT_STATUS_OBSOLETING_PERIOD",
        validationSchema={"type": "number", "exclusiveMinimum": 0, "maximum": 86400},
        defaultValue=60,
        description="video manager agent status obsoleting period, sec",
        services=["luna-video-manager"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_VIDEO_MANAGER_STREAMS_AGENT_SEARCH_INTERVAL",
        validationSchema={"type": "number", "exclusiveMinimum": 0, "maximum": 86400},
        defaultValue=5,
        description="video manager searching agent for streams execution interval, sec",
        services=["luna-video-manager"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_VIDEO_MANAGER_AGENT_STATUS_OBSOLETING_INTERVAL",
        validationSchema={"type": "number", "exclusiveMinimum": 0, "maximum": 86400},
        defaultValue=10,
        description="video manager agent status obsoleting calculation execution interval, sec",
        services=["luna-video-manager"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_VIDEO_MANAGER_STREAMS_AUTORESTARTER_INTERVAL",
        validationSchema={"type": "number", "exclusiveMinimum": 0, "maximum": 86400},
        defaultValue=5,
        description="video manager agent streams autorestarter execution interval, sec",
        services=["luna-video-manager"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_VIDEO_MANAGER_STREAM_STATUS_OBSOLETING_INTERVAL",
        validationSchema={"type": "number", "exclusiveMinimum": 0, "maximum": 86400},
        defaultValue=5,
        description="video manager stream status obsoleting calculation execution interval, sec",
        services=["luna-video-manager"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_SENDER_TIMEOUTS",
        validationSchema={
            "type": "object",
            "properties": {
                "request": {"type": "number", "exclusiveMinimum": 0},
                "connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_read": {"type": "number", "exclusiveMinimum": 0},
            },
            "description": "timeouts in seconds",
            "additionalProperties": False,
        },
        defaultValue={
            "request": 60,
            "connect": 20,
            "sock_connect": 10,
            "sock_read": 60,
        },
        description="timeouts for http-request to luna-sender service",
        services=["luna-video-agent"],
        groupNames=["luna-platform"],
    )

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)

    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)


def downgrade():
    """Downgrade configs to previous revision"""

    # limitations to modify
    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)

    # limitations to remove
    mh.removeLimitation(limitationName="LUNA_VIDEO_MANAGER_ACTIVE_PLUGINS")
    mh.removeLimitation(limitationName="LUNA_VIDEO_MANAGER_HTTP_SETTINGS")
    mh.removeLimitation(limitationName="LUNA_VIDEO_MANAGER_LOGGER")
    mh.removeLimitation(limitationName="LUNA_VIDEO_MANAGER_DB")
    mh.removeLimitation(limitationName="LUNA_VIDEO_MANAGER_STREAM_STATUS_OBSOLETING_PERIOD")
    mh.removeLimitation(limitationName="LUNA_VIDEO_AGENT_ACTIVE_PLUGINS")
    mh.removeLimitation(limitationName="LUNA_VIDEO_AGENT_HTTP_SETTINGS")
    mh.removeLimitation(limitationName="LUNA_VIDEO_AGENT_LOGGER")
    mh.removeLimitation(limitationName="LUNA_VIDEO_AGENT_RUNTIME_SETTINGS")
    mh.removeLimitation(limitationName="LUNA_VIDEO_AGENT_VIDEO_SETTINGS")
    mh.removeLimitation(limitationName="LUNA_VIDEO_MANAGER_ADDRESS")
    mh.removeLimitation(limitationName="LUNA_VIDEO_MANAGER_TIMEOUTS")
    mh.removeLimitation(limitationName="LUNA_VIDEO_AGENT_PEOPLE_COUNT_ESTIMATOR_SETTINGS")
    mh.removeLimitation(limitationName="LUNA_VIDEO_MANAGER_AGENT_STATUS_OBSOLETING_PERIOD")
    mh.removeLimitation(limitationName="LUNA_VIDEO_MANAGER_STREAMS_AGENT_SEARCH_INTERVAL")
    mh.removeLimitation(limitationName="LUNA_VIDEO_MANAGER_AGENT_STATUS_OBSOLETING_INTERVAL")
    mh.removeLimitation(limitationName="LUNA_VIDEO_MANAGER_STREAMS_AUTORESTARTER_INTERVAL")
    mh.removeLimitation(limitationName="LUNA_VIDEO_MANAGER_STREAM_STATUS_OBSOLETING_INTERVAL")
    mh.removeLimitation(limitationName="LUNA_SENDER_TIMEOUTS")
