"""
Configs migration

Generation datetime: 2024-06-26 10:20:40.770312
"""

from configs_core.migration.db_migrate_helper import (
    DatabaseMigrationHelper,
    ExternalLimitationToModify,
    LimitationToModify,
)

mh: DatabaseMigrationHelper

REVISION = "636532ad"
DOWN_REVISION = "391471e5"


def upgradeFaceDetV3Setting(setting: dict) -> dict:
    """Upgrade FaceDetV3 setting."""
    if setting.get("estimator_settings", {}).get("redetect_score_threshold") == 0.3:
        setting["estimator_settings"]["redetect_score_threshold"] = 0.5
    return setting


def downgradeFaceDetV3Setting(setting: dict) -> dict:
    """Downgrade FaceDetV3 setting."""
    if setting.get("estimator_settings", {}).get("redetect_score_threshold") == 0.5:
        setting["estimator_settings"]["redetect_score_threshold"] = 0.3
    return setting


limitationsToModify: list[LimitationToModify] = [
    LimitationToModify(
        limitationName="LUNA_REMOTE_SDK_FACE_DETECTOR_SETTINGS",
        oldDefaultValue={
            "runtime_settings": {
                "device_class": "global",
                "optimal_batch_size": 10,
                "worker_count": 1,
            },
            "estimator_settings": {
                "min_face_size": 50,
                "redetect_tensor_size": 80,
                "redetect_face_target_size": 64,
                "redetect_score_threshold": 0.3,
                "score_threshold": 0.5,
            },
        },
        newDefaultValue={
            "runtime_settings": {
                "device_class": "global",
                "optimal_batch_size": 10,
                "worker_count": 1,
            },
            "estimator_settings": {
                "min_face_size": 50,
                "redetect_tensor_size": 80,
                "redetect_face_target_size": 64,
                "redetect_score_threshold": 0.5,
                "score_threshold": 0.5,
            },
        },
        settingUpgradeFunction=upgradeFaceDetV3Setting,
        settingDowngradeFunction=downgradeFaceDetV3Setting,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-remote-sdk"],
        newServices=["luna-remote-sdk"],
    ),
]

externalLimitationsToModify: list[ExternalLimitationToModify] = []


def upgrade():
    """Upgrade configs to new revision"""

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)

    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)


def downgrade():
    """Downgrade configs to previous revision"""

    # limitations to modify
    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)
