"""
Configs migration

Generation datetime: 2024-09-11 13:17:32.111298
"""

from configs_core.migration.db_migrate_helper import (
    DatabaseMigrationHelper,
    ExternalLimitationToModify,
    LimitationToModify,
)

mh: DatabaseMigrationHelper

REVISION = "36b97d19"
DOWN_REVISION = "e7b16817"


limitationsToModify: list[LimitationToModify] = [
    LimitationToModify(
        limitationName="LUNA_REMOTE_SDK_VIDEO_SETTINGS",
        oldValidationSchema={
            "type": "object",
            "properties": {
                "decoder_device_class": {
                    "type": "string",
                    "enum": ["cpu", "gpu", "auto"],
                },
                "decoder_worker_count": {"type": "integer", "minimum": 1},
                "storage": {"type": "string"},
                "max_size": {"type": "integer", "minimum": 1},
                "timeouts": {
                    "type": "object",
                    "properties": {
                        "request": {"type": "number", "exclusiveMinimum": 0},
                        "connect": {"type": "number", "exclusiveMinimum": 0},
                        "sock_connect": {"type": "number", "exclusiveMinimum": 0},
                        "sock_read": {"type": "number", "exclusiveMinimum": 0},
                    },
                    "description": "timeouts in seconds",
                    "additionalProperties": False,
                },
            },
            "description": "sdk video processing settings",
            "additionalProperties": False,
        },
        newValidationSchema={
            "type": "object",
            "properties": {
                "decoder_device_class": {
                    "type": "string",
                    "enum": ["cpu", "gpu", "auto"],
                },
                "decoder_worker_count": {"type": "integer", "minimum": 1},
                "storage": {"type": "string"},
                "max_size": {"type": "integer", "minimum": 1},
                "timeouts": {
                    "type": "object",
                    "properties": {
                        "request": {"type": "number", "exclusiveMinimum": 0},
                        "connect": {"type": "number", "exclusiveMinimum": 0},
                        "sock_connect": {"type": "number", "exclusiveMinimum": 0},
                        "sock_read": {"type": "number", "exclusiveMinimum": 0},
                    },
                    "description": "timeouts in seconds",
                    "additionalProperties": False,
                },
                "frame_pool_size": {"type": "integer", "minimum": 1},
                "ffmpeg_thread_count": {"type": "integer", "minimum": 0},
            },
            "description": "sdk video processing settings",
            "additionalProperties": False,
        },
        oldDefaultValue={
            "decoder_device_class": "auto",
            "decoder_worker_count": 10,
            "storage": "./videos",
            "max_size": 1024,
            "timeouts": {
                "connect": 30.0,
                "request": 60.0,
                "sock_connect": 10.0,
                "sock_read": 60.0,
            },
        },
        newDefaultValue={
            "decoder_device_class": "auto",
            "decoder_worker_count": 10,
            "frame_pool_size": 10,
            "ffmpeg_thread_count": 0,
            "storage": "./videos",
            "max_size": 1024,
            "timeouts": {
                "connect": 30.0,
                "request": 60.0,
                "sock_connect": 10.0,
                "sock_read": 60.0,
            },
        },
        oldDescription="luna-remote-sdk video processing settings",
        newDescription="luna-remote-sdk video processing settings",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=None,
        settingDowngradeFunction=None,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-remote-sdk"],
        newServices=["luna-remote-sdk"],
    ),
    LimitationToModify(
        limitationName="LUNA_VIDEO_AGENT_VIDEO_SETTINGS",
        oldValidationSchema={
            "type": "object",
            "properties": {
                "decoder_device_class": {
                    "type": "string",
                    "enum": ["cpu", "gpu", "auto"],
                },
                "decoder_worker_count": {"type": "integer", "minimum": 1},
                "max_size": {"type": "integer", "minimum": 1},
                "timeouts": {
                    "type": "object",
                    "properties": {
                        "request": {"type": "number", "exclusiveMinimum": 0},
                        "connect": {"type": "number", "exclusiveMinimum": 0},
                        "sock_connect": {"type": "number", "exclusiveMinimum": 0},
                        "sock_read": {"type": "number", "exclusiveMinimum": 0},
                    },
                    "description": "timeouts in seconds",
                    "additionalProperties": False,
                },
            },
            "description": "video processing settings",
            "additionalProperties": False,
        },
        newValidationSchema={
            "type": "object",
            "properties": {
                "decoder_device_class": {
                    "type": "string",
                    "enum": ["cpu", "gpu", "auto"],
                },
                "decoder_worker_count": {"type": "integer", "minimum": 1},
                "max_size": {"type": "integer", "minimum": 1},
                "timeouts": {
                    "type": "object",
                    "properties": {
                        "request": {"type": "number", "exclusiveMinimum": 0},
                        "connect": {"type": "number", "exclusiveMinimum": 0},
                        "sock_connect": {"type": "number", "exclusiveMinimum": 0},
                        "sock_read": {"type": "number", "exclusiveMinimum": 0},
                    },
                    "description": "timeouts in seconds",
                    "additionalProperties": False,
                },
                "frame_pool_size": {"type": "integer", "minimum": 1},
                "ffmpeg_thread_count": {"type": "integer", "minimum": 0},
            },
            "description": "video processing settings",
            "additionalProperties": False,
        },
        oldDefaultValue={
            "decoder_device_class": "auto",
            "decoder_worker_count": 10,
            "max_size": 2048,
            "timeouts": {
                "connect": 30.0,
                "request": 60.0,
                "sock_connect": 10.0,
                "sock_read": 60.0,
            },
        },
        newDefaultValue={
            "decoder_device_class": "auto",
            "decoder_worker_count": 10,
            "frame_pool_size": 10,
            "ffmpeg_thread_count": 0,
            "max_size": 2048,
            "timeouts": {
                "connect": 30.0,
                "request": 60.0,
                "sock_connect": 10.0,
                "sock_read": 60.0,
            },
        },
        oldDescription="luna-video-agent video processing settings",
        newDescription="luna-video-agent video processing settings",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=None,
        settingDowngradeFunction=None,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-video-agent"],
        newServices=["luna-video-agent"],
    ),
]

externalLimitationsToModify: list[ExternalLimitationToModify] = []


def upgrade():
    """Upgrade configs to new revision"""

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)

    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)


def downgrade():
    """Downgrade configs to previous revision"""

    # limitations to modify
    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)
