"""
Module contains settings class for luna-sender
"""

from typing import Optional

from ..services.base_python_service_settings import BasePythonServiceSettingsClass
from ..settings.classes import RedisDBSetting as _RedisDBSetting


class SettingsSender(BasePythonServiceSettingsClass):
    """
    Settings class for luna-sender
    Attributes:
        senderDB (RedisDBSetting): redis database settings
    """

    serviceName = "luna-sender"

    def __init__(self):
        super().__init__()
        self.senderDB: Optional[_RedisDBSetting] = None

    def applySettings(self):
        """
        Deserialize loaded settings to classes
        """
        super().applySettings()
        self.senderDB = _RedisDBSetting(self.serviceName, self["REDIS_DB_ADDRESS"])
